# trackmania-records - Uploader (client)

This is the uploader for trackmania-records, a Trackmania 2020 records sharing/comparison tool.

The uploader extracts your records for the training maps of the latest Trackmania version (from 2020)
and uploads them to the web application server so you can easily share your records with friends.

Install (requires Python 3 on your system):

	pip3 install upload-tm-records

Update:

	pip3 install --upgrade upload-tm-records

Usage:

	upload-tm-records http://example.com/upload.php
